@@ -1,4 +1,4 @@
-# $Id: Split.pm,v 1.10.2.3 2001/05/21 19:05:27 jason Exp $
+# $Id: Split.pm,v 1.10.2.4 2001/11/01 00:59:08 jason Exp $
 #
 # BioPerl module for Bio::Location::SplitLocation
 # Cared for by Jason Stajich <jason@chg.mc.duke.edu>
@@ -126,7 +126,8 @@ sub sub_Location {
     $order = 1 if($order > 1);
     $order = -1 if($order < -1);
 
-    my @sublocs = @{$self->{'_sublocations'}};
+    my @sublocs = defined $self->{'_sublocations'} ? 
+	          @{$self->{'_sublocations'}} : ();
 
     # return the array if no ordering requested
     return @sublocs if( ($order == 0) || (! @sublocs) );
