@@ -1,4 +1,4 @@
-# $Id: PrimarySeq.pm,v 1.24.2.3 2001/04/01 05:51:32 lapp Exp $
+# $Id: PrimarySeq.pm,v 1.24.2.5 2001/10/26 19:06:03 jason Exp $
 #
 # bioperl module for Bio::PrimarySeq
 #
@@ -184,6 +184,13 @@ BEGIN {
            initialize by the parameter -moltype. See moltype() for possible
            values.
  Returns : a new Bio::PrimarySeq object
+ Args    : -seq         => sequence string
+           -display_id  => display id of the sequence (locus name) 
+           -accession_number => accession number
+           -primary_id  => primary id (Genbank id)
+           -desc        => description text
+           -moltype     => molecule type (dna,rna,prot)
+           -id          => alias for display id
 
 =cut
 
@@ -448,6 +455,7 @@ sub primary_id {
 sub moltype {
     my ($obj,$value) = @_;
     if (defined $value) {
+	$value = lc $value; # let's just make it lowercase consistently
 	unless ( $valid_type{$value} ) {
 	    $obj->throw("Molecular type '$value' is not a valid type (".
 			join(',', map "'$_'", sort keys %valid_type) .") lowercase");
