@@ -1,4 +1,4 @@
-# $Id: PrimarySeqI.pm,v 1.26.2.1 2001/03/02 22:47:54 heikki Exp $
+# $Id: PrimarySeqI.pm,v 1.26.2.4 2001/11/15 14:04:49 heikki Exp $
 #
 # BioPerl module for Bio::PrimarySeqI
 #
@@ -356,7 +356,7 @@ are encouraged to override these methods
            is the reversed complement of the sequence. For protein
            sequences this throws an exception of "Sequence is a protein. Cannot revcom"
 
-           The id is the same id as the orginal sequence, and the accession number
+           The id is the same id as the original sequence, and the accession number
            is also indentical. If someone wants to track that this sequence has be
            reversed, it needs to define its own extensions
 
@@ -797,7 +797,7 @@ sub _attempt_to_load_Seq{
 	   if( $self->can('throw') ) {
 	       $self->throw("Bio::PrimarySeq could not be loaded for $self\nThis indicates that you are usnig Bio::PrimarySeqI without Bio::PrimarySeq loaded and without providing a complete solution\nThe most likely problem is that there has been a misconfiguration of the bioperl environment\nActual exception\n\n$@\n");
 	   } else {
-	       confess("Bio::PrimarySeq could not be loaded for $self\nThis indicates that you are usnig Bio::PrimarySeqI without Bio::PrimarySeq loaded and without providing a complete solution\nThe most likely problem is that there has been a misconfiguration of the bioperl environment\nActual exception\n\n$@\n");
+	       confess("Bio::PrimarySeq could not be loaded for $self\nThis indicates that you are using Bio::PrimarySeqI without Bio::PrimarySeq loaded and without providing a complete solution\nThe most likely problem is that there has been a misconfiguration of the bioperl environment\nActual exception\n\n$@\n");
 	   }
 	   return 0;
        }
