@@ -1,4 +1,4 @@
-# $Id: flat.pm,v 1.6 2001/01/08 16:27:58 heikki Exp $
+# $Id: flat.pm,v 1.6.2.3 2001/06/21 15:36:06 heikki Exp $
 # BioPerl module for Bio::Variation::IO::flat
 #
 # Cared for by Heikki Lehvaslaiho <Heikki@ebi.ac.uk>
@@ -70,7 +70,7 @@ methods. Internal methods are usually preceded with a _
 # Let the code begin...
 
 package Bio::Variation::IO::flat;
-my $VERSION=1.0;
+my $version=1.0;
 use vars qw(@ISA);
 use strict;
 
@@ -158,15 +158,16 @@ sub next {
 	} else {
 	    $upflank =~ s/[ \n]//g;
 	    $dnflank =~ s/[ \n]//g;
-	    my ($region, $region_value) =  $dna =~ m|.+/region: (\w+); (\w+)|s ;
+	    my ($region, $junk, $region_value, $junk2, $region_dist) =  
+		$dna =~ m|.+/region: ([\w\']+)(; )?(\w+)?( ?\(\+?)?(-?\d+)?|s;
 	    #my $s = join ("|", $mut_number, $proof, $location, $upflank, 
-	    #	     $change, $dnflank, $region, $region_value);
+	    #	     $change, $dnflank, $region, $region_value, $region_dist, $1,$2,$3,$4,$5);
 	    #$self->warn($s);
 	    #exit;
 	    my ($start, $sep, $end) = $location =~ /(-?\d+)(.)?\D?(-?\d+)?/;
 	    $end = $start if not $end ;
 	    my ($len) = $end - $start +1; 
-	    $len = 0 if defined $sep and $sep eq '^';
+	    $len = 0, $start = $end if defined $sep and $sep eq '^';
 	    my $ismut = 0;
 	    $ismut = 1 if $change =~ m/>/; 
 	    
@@ -190,10 +191,10 @@ sub next {
 		$dnamut->isMutation(1);
 		$dnamut->allele_mut($a2);
 	    }
-	    if (defined $region) {
-		$dnamut->region($region);
-		$dnamut->region_value($region_value);
-	    }
+	    $dnamut->region($region) if defined $region;
+	    $dnamut->region_value($region_value) if defined $region_value;
+	    $dnamut->region_dist($region_dist) if defined $region_dist;
+
 	    $h->add_Variant($dnamut);
 	    $dnamut->SeqDiff($h);
 	}
@@ -210,11 +211,12 @@ sub next {
 	$rna =~ s/Feature[ \t]+//g;
 	($rna) = split "DNA; ", $rna; 
 	#$self->warn("|$rna|") ;
-	my ($mut_number, $proof, $location, $upflank, $change, $dnflank, $region) = 
-	    $rna =~ m|\W+([\d\.]+).+/proof: (\w+).+/location: ([^ \n]+).+/upflank: (\w+).+/change: ([^/]+).+/dnflank: (\w+).+/region: (\S+)|s ;#'
-	
+	my ($mut_number, $proof, $location, $upflank, $change, $dnflank) = 
+	    $rna =~ m|\W+([\d\.]+).+/proof: (\w+).+/location: ([^ \n]+).+/upflank: (\w+).+/change: ([^/]+).+/dnflank: (\w+)|s ;#'
+	my ($region, $junk, $region_value, $junk2, $region_dist) =  
+	    $rna =~ m|.+/region: ([\w\']+)(; )?(\w+)?( ?\(\+?)?(-?\d+)?|s;
 	#my $s = join ("|", $mut_number, $proof, $location, $upflank, 
-	#	     $change, $dnflank, $region);
+	#	      $change, $dnflank, $region, $region_value, $region_dist, $1,$2,$3,$4,$5);
 	#$self->warn($s);
 	#exit;
 	$change =~ s/[ \n]//g;	
@@ -230,7 +232,7 @@ sub next {
 	    my ($start, $sep, $end) = $location =~ /(-?\d+)(.)?\D?(-?\d+)?/;
 	    $end = $start if not $end ;
 	    my ($len) = $end - $start + 1; 
-	    $len = 0 if defined $sep and $sep eq '^'; 
+	    $len = 0, $start = $end if defined $sep and $sep eq '^'; 
 	    my $ismut;
 	    $ismut = 1 if $change =~ m/>/; 
 	    my ($codon_table) = $rna =~ m|.+/codon_table: (\d+)|s;
@@ -243,7 +245,6 @@ sub next {
 		 '-upStreamSeq'   => $upflank,
 		 '-dnStreamSeq'   => $dnflank,
 		 '-proof'         => $proof,
-		 '-region'        => $region,
 		 '-mut_number'    => $mut_number
 		 
 		 );
@@ -258,6 +259,10 @@ sub next {
 		$rnamut->isMutation(1);
 		$rnamut->allele_mut($a2);
 	    }
+	    $rnamut->region($region) if defined $region;
+	    $rnamut->region_value($region_value) if defined $region_value;
+	    $rnamut->region_dist($region_dist) if defined $region_dist;
+
 	    $rnamut->codon_table($codon_table) if $codon_table;
 	    $rnamut->codon_pos($codon_pos) if $codon_pos;
 	    $h->add_Variant($rnamut);
@@ -297,13 +302,12 @@ sub next {
 	if ($change_number and $change_number > 1 ) {
 	    my $a3 = Bio::Variation::Allele->new;
 	    $a3->seq($mut) if $mut;
-	    #$aamut->add_Allele($a3);
 	    $prevaaobj->add_Allele($a3);
 	} else {
 	    my ($start, $sep, $end) = $location =~ /(-?\d+)(.)?\D?(-?\d+)?/;
 	    $end = $start if not $end ;
 	    my ($len) = $end - $start + 1; 
-	    $len = 0 if defined $sep and $sep eq '^'; 
+	    $len = 0, $start = $end if defined $sep and $sep eq '^'; 
 	    my $ismut;
 	    $ismut = 1 if $change =~ m/>/; 
 	    my ($region) =  $aa =~ m|.+/region: (\w+)|s ;	
@@ -361,8 +365,8 @@ sub write {
 	 'ID'               => 'ID           ',
 	 'Description'      => 'Description  ',
 	 'FeatureKey'       => 'Feature      ',
-	 'FeatureQual'      => 'Feature        ',
-	 'FeatureWrap'      => 'Feature         ',
+	 'FeatureQual'      => "Feature        ",
+	 'FeatureWrap'      => "Feature         ",
 	 'ErrorComment'     => 'Comment      '
 	 #'Comment'          => 'Comment      -!-',
 	 #'CommentLine'      => 'Comment         ',
@@ -374,10 +378,6 @@ sub write {
 
     foreach my $h (@h) {
 	
-	# HTML | ASCII
-	#my ($mode) = @args;
-	my $mode = '';#= 'ASCII' if not defined $mode;
-	
 	my @entry =();
     
 	my ($text, $tmp, $tmp2, $sep);
@@ -386,12 +386,7 @@ sub write {
 	
 	$text = $tag{ID};
 	
-	if ($mode eq 'HTML' ) {
-	    $text .= '<A HREF=http://srs.ebi.ac.uk/srs6bin/cgi-bin/wgetz?-e+'.
-		'[embl-acc:'. $h->id. ']>'. $h->id. '</A>';
-	} else {
-	    $text .= $h->id;
-	}
+	$text .= $h->id;
 	$text .= ":(". $h->offset;
 	$text .= "+1" if $h->sysname =~ /-/;
 	$text .= ")".  $h->sysname;
@@ -405,15 +400,8 @@ sub write {
 	my @allvariants = $h->each_Variant;
 	my %variants = ();
 	foreach my $mut ($h->each_Variant) {
-	    #print STDERR  $mut->mut_number, "\t", $mut, "\t", $mut->proof, "\t", scalar $mut->each_Allele,  "\n";	    
 	    push @{$variants{$mut->mut_number} }, $mut; 
 	}
-	#print "-----------\n";
-#	 foreach my $var (sort keys %variants) {
-#	     print "variation: ",  scalar $var, "\n";
-#	 }
-	#exit;
-	#print "variation: ",  scalar $var, "\n";
 	#my ($variation_number, $change_number) = split /\./, $mut_number;
 	foreach my $var (sort keys %variants) {
 	    #print $var, ": ", join (" ", @{$variants{$var}}), "\n";	
@@ -454,31 +442,36 @@ sub write {
 			     push (@entry, $text) ;
 			 }
 			 #location
-			 $text = $tag{FeatureQual}. '/location: '. 
+			 $text = $tag{FeatureQual}. '/location: '; 
 			     #$mut->id. '; '. $mut->start; 
-			     $mut->start; 
-			 
 			 if ($mut->length > 1 ) {#	    if ($mut->end - $mut->start ) {
 			     my $l = $mut->start + $mut->length -1;
-			     $text .= '..'.  $l;
+			     $text .= $mut->start. '..'.  $l;
 			 }
 			 elsif ($mut->length == 0) {
-			     $text .= '^'. $mut->end;
+			     my $tmp_start = $mut->start - 1;
+			     $tmp_start-- if $tmp_start == 0;
+			     $text .= $tmp_start. '^'. $mut->end;
+			 } else {
+			     $text .= $mut->start;
 			 }
+
 			 if ($h->moltype && $h->moltype eq 'dna') {
 			     $tmp = $mut->start + $h->offset;
-			     if ($tmp <= 0) {
-				 $tmp -= 1;
-			     }
+			     $tmp-- if $tmp <= 0;
 			     $mut->start < 1 && $tmp++; 
-			     $text.= ' ('. $h->id. '::'. $tmp;
+			     #$text.= ' ('. $h->id. '::'. $tmp;
 			     $tmp2 = $mut->end + $h->offset;
 			     if ( $mut->length > 1 ) {
 				 $mut->end < 1 && $tmp2++; 
-				 $text.= "..". $tmp2;
+				 $text.= ' ('. $h->id. '::'. $tmp. "..". $tmp2;
 			     }
 			     elsif ($mut->length == 0) {
-				 $text .= '^'. $tmp2;
+				 $tmp--;
+				 $tmp-- if $tmp == 0;
+				 $text .= ' ('. $h->id. '::'. $tmp. '^'. $tmp2;
+			     } else {
+				 $text.= ' ('. $h->id. '::'. $tmp;
 			     }
 			     $text .= ')';
 			 }
@@ -501,41 +494,24 @@ sub write {
 			       );
 			 #restriction enzyme
 			 if ($mut->restriction_changes ne '') {
-			     if ($mode eq 'HTML') {
-				 my @enz = split ', ', $mut->restriction_changes;
-				 my ($rtmp, @tmp);
-				 foreach $rtmp (@enz) {
-				     $rtmp =~ s/([+-])(.*)/$2\]\>$1$2/;
-				     $rtmp = '<A HREF=http://srs.ebi.ac.uk/srs6bin/cgi-bin/wgetz?-e+[rebase-id:'. 
-					 $rtmp. '</A>';
-				     push (@tmp, $rtmp);
-				 }
-				 $text = join ('; ', sort(@tmp));
-			     } else {
-				 $text = $mut->restriction_changes;
-				 $text = wrap($tag{FeatureQual}. '/re_site: ', $tag{FeatureWrap}, $text); 
-			     }
+			     $text = $mut->restriction_changes;
+			     $text = wrap($tag{FeatureQual}. '/re_site: ', $tag{FeatureWrap}, $text); 
 			     push (@entry,
 				   $text
 				   );
 			 }
 			 #region
 			 if ($mut->region ) {
-			     push (@entry,  
-				   $tag{FeatureQual}. '/region: '. 
-				   $mut->region. '; '. $mut->region_value
-				   );
+			     $text = $tag{FeatureQual}. '/region: '. $mut->region;
+			     $text .= ';' if $mut->region_value or $mut->region_dist; 
+			     $text .= ' '. $mut->region_value if $mut->region_value;
+			     if ($mut->region_dist ) {
+				 $tmp = '';
+				 $tmp = '+' if $mut->region_dist > 1;
+				 $text .= " (". $tmp. $mut->region_dist. ')';
+			     }
+			     push (@entry, $text);
 			 }
-			 #splice dist	  
-			 #if ($mut->param('molecule') eq "DNA") {
-			 #   if (abs $mut->param('splicedist') < 10 ) {
-			 #      	 push (@entry,  
-			 #      		$tag{FeatureQual}. '/splicedist: '. $mut->param('splicedist')
-			 #      		);
-			 #        }
-			 #   }
-			 #
-
 			 #CpG
 			 if ($mut->CpG) {
 			     push (@entry,  
@@ -579,32 +555,37 @@ sub write {
 			     push (@entry, $text) ;
 			 }
 			 #location
-			 $text = $tag{FeatureQual}. '/location: '. 
-			     $mut->start; 
-			 
+			 $text = $tag{FeatureQual}. '/location: ' ; 
 			 if ($mut->length > 1 ) {
-			     $text .= '..'. $mut->end;
-			     
+			     $text .= $mut->start. '..'. $mut->end;
 			     $tmp2 = $mut->end + $h->offset;
 			 }
 			 elsif ($mut->length == 0) {
-			     $text .= '^'. $mut->end;
+			     my $tmp_start = $mut->start;
+			     $tmp_start--;
+			     $tmp_start-- if $tmp_start == 0;
+			     $text .= $tmp_start. '^'. $mut->end;
+			 } else {
+			     $text .= $mut->start;
 			 }
+
 			 if ($h->moltype && $h->moltype eq 'rna') {
 			     $tmp = $mut->start + $h->offset;
-			     if ($tmp <= 0) {
-				 $tmp -= 1;
-			     }
+			     $tmp-- if $tmp <= 0;
 			     #$mut->start < 1 && $tmp++;			     
-			     $text.= ' ('. $h->id. '::'. $tmp;
+			     #$text.= ' ('. $h->id. '::'. $tmp;
 			     $tmp2 = $mut->end + $h->offset;
 			     #$mut->end < 1 && $tmp2++; 
 			     if ( $mut->length > 1 ) {
-				 $text.= "..". $tmp2;
+				 $text.= ' ('. $h->id. '::'. $tmp. "..". $tmp2;
 			     }
 			     elsif ($mut->length == 0) {
-				 $text .= '^'. $tmp2;
+				 $tmp--;
+				 $text .= ' ('. $h->id. '::'. $tmp. '^'. $tmp2;
+			     } else {
+				 $text.= ' ('. $h->id. '::'. $tmp;
 			     }
+
 			     $text .= ')';
 			 }
 			 push (@entry, $text);
@@ -626,20 +607,8 @@ sub write {
 			       );
 			 #restriction
 			 if ($mut->restriction_changes ne '') {
-			     if ($mode eq 'HTML') {
-				 my @enz = split ', ', $mut->restriction_changes;
-				 my ($rtmp, @tmp);
-				 foreach $rtmp (@enz) {
-				     $rtmp =~ s/([+-])(.*)/$2\]\>$1$2/;
-				     $rtmp = '<A HREF=http://srs.ebi.ac.uk/srs6bin/cgi-bin/wgetz?-e+[rebase-id:'. 
-					 $rtmp. '</A>';
-				     push (@tmp, $rtmp);
-				 }
-				 $text = join ('; ', sort(@tmp));
-			     } else {
-				 $text = $mut->restriction_changes;
-				 $text = wrap($tag{FeatureQual}. '/re_site: ', $tag{FeatureWrap}, $text); 
-			     }
+			     $text = $mut->restriction_changes;
+			     $text = wrap($tag{FeatureQual}. '/re_site: ', $tag{FeatureWrap}, $text); 
 			     push (@entry,
 				   $text
 				   );
@@ -648,13 +617,7 @@ sub write {
 			 if ($mut->region eq 'coding') {
 			     #codon table
 			     $text =  $tag{FeatureQual}. '/codon_table: ';
-			     if ($mode eq 'HTML' ) {
-				 $text .=  "<A HREF=http://www.ebi.ac.uk/cgi-bin/mutations/trtables.cgi?".
-				     "id=". $mut->codon_table. "&Action=Show>".
-					 $mut->codon_table.  '</A>';
-			     } else {
-				 $text .= $mut->codon_table;
-			     }
+			     $text .= $mut->codon_table;
 			     push (@entry, $text);
 			     #codon
 
@@ -670,9 +633,15 @@ sub write {
 			 }
 			 #region
 			 if ($mut->region ) {
-			     push (@entry,  
-				   $tag{FeatureQual}. '/region: '. $mut->region
-				   );
+			     $text = $tag{FeatureQual}. '/region: '. $mut->region;
+			     $text .= ';' if $mut->region_value or $mut->region_dist; 
+			     $text .= ' '. $mut->region_value if $mut->region_value;
+			     if ($mut->region_dist ) {
+				 $tmp = '';
+				 $tmp = '+' if $mut->region_dist > 1;
+				 $text .= " (". $tmp. $mut->region_dist. ')';
+			     }
+			     push (@entry, $text);
 			 }
 		     }
 		 }
@@ -729,19 +698,26 @@ sub write {
 			       );
 			 #region
 			 if ($mut->region ) {
-			     push (@entry,  
-				   $tag{FeatureQual}. '/region: '. $mut->region
-				   );
+			     $text = $tag{FeatureQual}. '/region: '. $mut->region;
+			     $text .= ';' if $mut->region_value or $mut->region_dist; 
+			     $text .= ' '. $mut->region_value if $mut->region_value;
+			     if ($mut->region_dist ) {
+				 $tmp = '';
+				 $tmp = '+' if $mut->region_dist > 1;
+				 $text .= " (". $tmp. $mut->region_dist. ')';
+			     }
+			     push (@entry, $text);
 			 }
 		     }
 		  }
 	     }
-	 }
-	 push (@entry, 
-	       "//"
-	       );  
-	 my $str = join ("\n", @entry). "\n";
-	 $self->_print($str);
+	}
+	push (@entry, 
+	      "//"
+	      );  
+	my $str = join ("\n", @entry). "\n";
+	$str =~ s/\t/        /g;
+	$self->_print($str);
     }
     return 1;
 }
